Djinn
=====

- Djinn is a micro-framework which wraps Tornado to make it easy to write a web application using Tornado.

- Djinn is originally created by Felinx Lee <felinx.lee@gmail.com> and opened to community under Apache License Version 2.0.

Notice
======
"djinn.db" is a fork from torndb  which is not actively maintained.
